@@ -34,7 +34,7 @@ class EzvizCamera:
         }
 
     def _detection_sensibility(self) -> Any:
-        """load detection sensibility"""
+        """Load detection sensitivity."""
         result = "Unknown"
 
         if self._switch.get(DeviceSwitchType.AUTO_SLEEP.value) is not True:
@@ -55,7 +55,7 @@ class EzvizCamera:
         return result
 
     def _alarm_list(self) -> None:
-        """get last alarm info for this camera's self._serial"""
+        """Get last alarm info for this camera's self._serial."""
         _alarmlist = self._client.get_alarminfo(self._serial)
 
         if _alarmlist["page"].get("totalResults") > 0:
@@ -63,21 +63,19 @@ class EzvizCamera:
             return self._motion_trigger()
 
     def _local_ip(self) -> Any:
-        """Fix empty ip value for certain cameras"""
-        if self._device.get("WIFI"):
-            if (
-                self._device["WIFI"].get("address")
-                and self._device["WIFI"]["address"] != "0.0.0.0"
-            ):
-                return self._device["WIFI"]["address"]
+        """Fix empty ip value for certain cameras."""
+        if (
+            self._device["WIFI"].get("address")
+            and self._device["WIFI"]["address"] != "0.0.0.0"
+        ):
+            return self._device["WIFI"]["address"]
 
         # Seems to return none or 0.0.0.0 on some.
-        if self._device.get("CONNECTION"):
-            if (
-                self._device["CONNECTION"].get("localIp")
-                and self._device["CONNECTION"]["localIp"] != "0.0.0.0"
-            ):
-                return self._device["CONNECTION"]["localIp"]
+        if (
+            self._device["CONNECTION"].get("localIp")
+            and self._device["CONNECTION"]["localIp"] != "0.0.0.0"
+        ):
+            return self._device["CONNECTION"]["localIp"]
 
         return "0.0.0.0"
 
@@ -103,14 +101,15 @@ class EzvizCamera:
         }
 
     def _is_alarm_schedules_enabled(self) -> bool:
-        """Checks if alarm schedules enabled"""
-        return bool(
-            [
-                item
-                for item in self._device.get("TIME_PLAN", {})
-                if item.get("type") == 2
-            ][0].get("enable")
-        )
+        """Check if alarm schedules enabled."""
+        _alarm_schedules = [
+            item for item in self._device.get("TIME_PLAN", {}) if item.get("type") == 2
+        ]
+
+        if _alarm_schedules:
+            return bool(_alarm_schedules[0].get("enable"))
+
+        return False
 
     def status(self) -> dict[Any, Any]:
         """Return the status of the camera."""
@@ -132,6 +131,10 @@ class EzvizCamera:
             "audio": self._switch.get(DeviceSwitchType.SOUND.value),
             "ir_led": self._switch.get(DeviceSwitchType.INFRARED_LIGHT.value),
             "state_led": self._switch.get(DeviceSwitchType.LIGHT.value),
+            "upgrade_percent": self._device["STATUS"].get("upgradeProcess"),
+            "upgrade_in_progress": bool(
+                self._device["STATUS"].get("upgradeStatus") == 0
+            ),
             "follow_move": self._switch.get(DeviceSwitchType.MOBILE_TRACKING.value),
             "alarm_notify": bool(self._device["STATUS"].get("globalStatus")),
             "alarm_schedules_enabled": self._is_alarm_schedules_enabled(),
@@ -140,7 +143,8 @@ class EzvizCamera:
             ).name,
             "encrypted": bool(self._device["STATUS"].get("isEncrypt")),
             "local_ip": self._local_ip(),
-            "wan_ip": self._device["CONNECTION"].get("netIp", "0.0.0.0"),
+            "wan_ip": self._device["CONNECTION"].get("netIp"),
+            "mac_address": self._device["deviceInfos"].get("mac"),
             "local_rtsp_port": self._device["CONNECTION"].get("localRtspPort", "554")
             if self._device["CONNECTION"].get("localRtspPort", "554") != 0
             else "554",
@@ -175,6 +179,10 @@ class EzvizCamera:
 
         return True
 
+    def move_coordinates(self, x_axis: float, y_axis: float) -> bool:
+        """Move camera to specified coordinates."""
+        return self._client.ptz_control_coordinates(self._serial, x_axis, y_axis)
+
     def alarm_notify(self, enable: int) -> bool:
         """Enable/Disable camera notification when movement is detected."""
         return self._client.set_camera_defence(self._serial, enable)
