@@ -26,6 +26,8 @@ from .exceptions import (
     PyEzvizError,
 )
 
+_LOGGER = logging.getLogger(__name__)
+
 API_ENDPOINT_CLOUDDEVICES = "/api/cloud/v2/cloudDevices/getAll"
 API_ENDPOINT_PAGELIST = "/v3/userdevices/v1/resources/pagelist"
 API_ENDPOINT_DEVICES = "/v3/devices/"
@@ -135,9 +137,8 @@ class EzvizClient:
 
         if json_result["meta"]["code"] == 1100:
             self._token["api_url"] = json_result["loginArea"]["apiDomain"]
-            print("Region incorrect!")
-            print(f"Your region url: {self._token['api_url']}")
-            self.close_session()
+            _LOGGER.warning("Region incorrect!")
+            _LOGGER.warning("Your region url: %s", self._token["api_url"])
             return self.login()
 
         if json_result["meta"]["code"] == 1013:
@@ -664,6 +665,9 @@ class EzvizClient:
 
             if json_result["meta"].get("code") == 200:
 
+                self._session.headers["sessionId"] = json_result["sessionInfo"][
+                    "sessionId"
+                ]
                 self._token["session_id"] = str(json_result["sessionInfo"]["sessionId"])
                 self._token["rf_session_id"] = str(
                     json_result["sessionInfo"]["refreshSessionId"]
@@ -706,7 +710,7 @@ class EzvizClient:
 
         except requests.HTTPError as err:
             if err.response.status_code == 401:
-                print("Token is no longer valid. Already logged out?")
+                _LOGGER.warning("Token is no longer valid. Already logged out?")
                 return True
             raise HTTPError from err
 
