@@ -18,8 +18,12 @@ class InvalidHost(PyEzvizError):
 
 
 class AuthTestResultFailed(PyEzvizError):
-    """Authentication failed"""
+    """Authentication failed."""
 
 
 class EzvizAuthTokenExpired(PyEzvizError):
-    """Authentication failed because token is invalid or expired"""
+    """Authentication failed because token is invalid or expired."""
+
+
+class EzvizAuthVerificationCode(PyEzvizError):
+    """Authentication failed because MFA verification code is required."""
